==> apache-storm-1.2.4-src.tar.gz: apache-storm-1.2.4/external/storm-eventhubs/src/main/java/org/apache/storm/eventhubs/trident/Partition.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/
package org.apache.storm.eventhubs.trident;

import java.io.Serializable;
import org.apache.storm.eventhubs.spout.EventHubSpoutConfig;
import org.apache.storm.trident.spout.ISpoutPartition;

/**
 * Represents an EventHub partition
 */
public class Partition implements ISpoutPartition, Serializable {
  private static final long serialVersionUID = 1L;
  String partitionId;
  
  public Partition(EventHubSpoutConfig config, String partitionId) {
    this.partitionId = partitionId;
  }
  
  @Override
  public String getId() {
    return partitionId;
  }
}

==> apache-storm-2.3.0-src.tar.gz: apache-storm-2.3.0/external/storm-eventhubs/src/main/java/org/apache/storm/eventhubs/trident/Partition.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

package org.apache.storm.eventhubs.trident;

import java.io.Serializable;
import org.apache.storm.eventhubs.spout.EventHubSpoutConfig;
import org.apache.storm.trident.spout.ISpoutPartition;

/**
 * Represents an EventHub partition.
 */
public class Partition implements ISpoutPartition, Serializable {
    private static final long serialVersionUID = 1L;
    String partitionId;

    public Partition(EventHubSpoutConfig config, String partitionId) {
        this.partitionId = partitionId;
    }

    @Override
    public String getId() {
        return partitionId;
    }
}
